import {
  config
} from '@/common/config.js';
import store from '../store/index.js'

// 这里的vm，就是我们在vue文件里面的this，所以我们能在这里获取vuex的变量，比如存放在里面的token
// 同时，我们也可以在此使用getApp().globalData，如果你把token放在getApp().globalData的话，也是可以使用的
const install = (Vue, vm) => {
  Vue.prototype.$u.http.setConfig({
    baseUrl: config.baseUrl,
		// 设置为json，返回后会对数据进行一次JSON.parse()
		dataType: 'json',
		showLoading: true, // 是否显示请求中的loading
		loadingText: '请求中...', // 请求loading中的文字提示
		loadingTime: 500, // 在此时间内，请求还没回来的话，就显示加载中动画，单位ms
		originalData: false, // 是否在拦截器中返回服务端的原始数据
		loadingMask: true, // 展示loading的时候，是否给一个透明的蒙层，防止触摸穿透
		// 配置请求头信息
		header: {
			'content-type': 'application/json;charset=UTF-8'
		}
  });
  // 请求拦截，配置Token等参数
  Vue.prototype.$u.http.interceptor.request = (config) => {
    // config.header.Token = 'xxxxxx';
    // 方式一，存放在vuex的token，假设使用了uView封装的vuex方式，见：https://uviewui.com/components/globalVariable.html
    // config.header.token = vm.vuex_token;

    if (vm.vuex_token) {
      config.header.Authorization = `Bearer ${vm.vuex_token}`;
    }

    // 方式二，如果没有使用uView封装的vuex方法，那么需要使用$store.state获取
    // config.header.token = vm.$store.state.token;

    // 方式三，如果token放在了globalData，通过getApp().globalData获取
    // config.header.token = getApp().globalData.username;

    // 方式四，如果token放在了Storage本地存储中，拦截是每次请求都执行的，所以哪怕您重新登录修改了Storage，下一次的请求将会是最新值
    // const token = uni.getStorageSync('token');
    // config.header.token = token;
    // url加时间戳
    config.url = config.url + '?t=' + Date.now()
    // 此url参数为this.$u.get(url)中的url值
    let noTokenList = ['/wechat/h5/user', '/client/auth/verifyCode'];
    if (noTokenList.includes(config.url)) config.header.noToken = true;
    // console.log('noTokenList.includes(config.url)',noTokenList.includes(config.url));
    // console.log('config.url',config.url);
    return config;
  }
  // 响应拦截，判断状态码是否通过
  Vue.prototype.$u.http.interceptor.response = (res) => {
    // 如果把originalData设置为了true，这里得到将会是服务器返回的所有的原始数据
    // 判断可能变成了res.statueCode，或者res.data.code之类的，请打印查看结果
    // console.log('interceptor res',res);
    if (res.code == 200) {
      // 如果把originalData设置为了true，这里return回什么，this.$u.post的then回调中就会得到什么
      return res;
    } else if (res.msg == "令牌不能为空" || res.code == 401) {
      const backUrl = location.href
      const loginUrl = 'phoneLogin'
      if (backUrl.indexOf(loginUrl) > 0) {
        // localStorage.clear()
      } else {
        localStorage.setItem('backUrl', location.href)
        store.state.vuex_hasLogin = false;
        alert('还未登录,即将跳转登录');
        uni.navigateTo({
          url: "/pages/phoneLogin/phoneLogin"
        });
        return;
      }

    } else if (res.code == 400) {
			uni.showToast({
				title: res.msg,
				icon: 'error'
			})
		}
  }
}

export default {
  install
}
